loleaflet/src/map/Clipboard.js |    6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

New commits:
commit 5bc28a9d3047e47c5b7210522e9d5729524c1f0e
Author:     Henry Castro <hcas...@collabora.com>
AuthorDate: Thu Feb 20 16:58:40 2020 -0400
Commit:     Henry Castro <hcas...@collabora.com>
CommitDate: Fri Feb 21 00:49:29 2020 +0100

    loleafet: ignore the paste event when a vex dialog...
    
    has the focus
    
    Change-Id: Ib6eece050c7b962087d229cf484c8873a214d359
    Reviewed-on: https://gerrit.libreoffice.org/c/online/+/89159
    Tested-by: Jenkins CollaboraOffice <jenkinscollaboraoff...@gmail.com>
    Reviewed-by: Henry Castro <hcas...@collabora.com>

diff --git a/loleaflet/src/map/Clipboard.js b/loleaflet/src/map/Clipboard.js
index 335314223..315fa1e90 100644
--- a/loleaflet/src/map/Clipboard.js
+++ b/loleaflet/src/map/Clipboard.js
@@ -3,7 +3,7 @@
  * L.Clipboard is used to abstract our storage and management of
  * local & remote clipboard data.
  */
 /* global _ vex brandProductName */
 
 // Get all interesting clipboard related events here, and handle
 // download logic in one place ...
@@ -648,6 +648,10 @@ L.Clipboard = L.Class.extend({
 
        paste: function(ev) {
                console.log('Paste');
+
+               if (isAnyVexDialogActive() && !this._map.hasFocus())
+                       return;
+
                if (this._map._activeDialog)
                        ev.usePasteKeyEvent = true;
 
@@ -3,7 +3,7 @@
  * local & remote clipboard data.
  */
-/* global _ vex brandProductName */
+/* global _ vex brandProductName isAnyVexDialogActive */
 
 // Get all interesting clipboard related events here, and handle
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to